@@ -596,7 +596,8 @@ class CommandV(Extensible):
         dump_path = 'dump.sql' if not self.__config.jobs else 'database_dump'
         dump_path = os.path.join(self.__config.temp_working_folder, dump_path)
         logger.info('Generating deactivated backup')
-        postgres.dump(db_name, dump_path, jobs=self.__config.jobs)
+        exclude = self.__config.postgres.get("exclude_tables") or ""
+        postgres.dump(db_name, dump_path, jobs=self.__config.jobs, exclude=exclude)
         backup_name = utils.generate_backup_name(db_name)
         files2backup = [dump_path]
         files = os.listdir(dest_dir)
@@ -717,7 +718,7 @@ class CommandV(Extensible):
         :rtype: dict
         """
         self.__config.check_config('updatedb')
-        res = {'command': 'updatedb'}
+        res = {'command': 'updatedb', 'must_parse': True}
         db_name = db_name or self.__config.instance_config.get('config').get('db_name')
         self.sender.send_message('Updating database "{}".'.format(db_name))
         try:
@@ -732,26 +733,20 @@ class CommandV(Extensible):
         res.update(update_res)
         if res.get('error'):
             logger.error(res['error'])
-            self.send_message_error(res)
-            return res
         self.__instance_manager.start_instance()
         res['result'].update({'database_name': db_name})
         install_module = self.__config.instance_config.get('install_module')
-        if install_module:
+        if install_module and not res.get('error'):
             self.sender.send_message('Installing module(s): {}.'.format(', '.join(install_module)))
             install_res = self.__instance_manager.install_module(install_module, db_name)
-            res['result'].update({
-                'install_module': install_res
-            })
+            res['result'].update({'install_module': install_res})
             if not res.get('attachments', False):
                 res.update({'attachments': []})
-            res.get('attachments').append(
-                {
-                    'file_name': os.path.basename(install_res.get('log_file')),
-                    'file': utils.generate_attachment(install_res.get('log_file')),
-                    'type': 'text/plain'
-                }
-            )
+            res.get('attachments').append({
+                'file_name': os.path.basename(install_res.get('log_file')),
+                'file': utils.generate_attachment(install_res.get('log_file')),
+                'type': 'text/plain'
+            })
         if not self.skip_push():
             image = self.__config.container_config.get('image_name')
             expr = r'(?P<url>[^/]*)/(?P<repo>.*):(?P<tag>.*)'
@@ -1021,7 +1016,7 @@ class CommandV(Extensible):
         return res
 
     def _check_update_production_requirements(self):
-        res = {'command': 'update_production', 'result': {}}
+        res = {'command': 'update_production', 'result': {}, 'must_parse': True}
         # Check images
         images_data = [
             {
@@ -1095,7 +1090,7 @@ class CommandV(Extensible):
             7. The backup is compressed inside the backup folder.
         """
         self.sender.send_message('Updating Production instance.')
-        res = {'command': 'update_production', 'result': {}}
+        res = {'command': 'update_production', 'result': {}, 'must_parse': True}
         self.__config.check_config('update_production')
         container_info = self.instance_manager.basic_info
         container_name = container_info.get('name')
