@@ -214,8 +214,11 @@ def backupdb(ctx, config_file, backup_dir, reason, tmp_dir, database, cformat,
 @click.option("--jobs", default=False, required=False, type=int,
               help=("The numbers of jobs parallel for restore the database."
                     " This option can dramatically reduce the time to restore database"))
+@click.option("--update-method", default='normal', required=False,
+              type=click.Choice(['normal', 'cou']),
+              help="Update the database using click-odoo-update")
 def restore(ctx, config_file, backup_src, database, container, admin_pass,
-            instance_type, prefix, nginx_url, jobs):
+            instance_type, prefix, nginx_url, jobs, update_method):
     """Restores a backup from a directory.
     """
     config_obj = ctx.parent.command.config_parser
@@ -250,7 +253,10 @@ def restore(ctx, config_file, backup_src, database, container, admin_pass,
     config_dict.get('group_config').update({'backup_src': backup_src} if backup_src else {})
     config_dict.get('group_config').update({'jobs': jobs} if jobs else {})
     config_dict.get('group_config').update({'prefix': prefix} if prefix else {})
-    config_dict.get('group_config').update({'command': 'deployvcmd.commandv.restore'})
+    config_dict.get('group_config').update({
+        'command': 'deployvcmd.commandv.restore',
+        'update_method': update_method
+    })
     config_obj.generate_configuration(config_dict)
     command = commandv.CommandV(config_obj)
     command.restore_trigger()
@@ -262,7 +268,10 @@ def restore(ctx, config_file, backup_src, database, container, admin_pass,
               default=False, required=True)
 @click.option("-d", "--database", help="Database name to be updated",
               default=False, required=False)
-def update(ctx, config_file, database):
+@click.option("--update-method", default='normal', required=False,
+              type=click.Choice(['normal', 'cou']),
+              help="Update the database using click-odoo-update")
+def update(ctx, config_file, database, update_method):
     """Updates an existing instance, clone the branches to the specified ones and updates database.
     """
     config_obj = ctx.parent.command.config_parser
@@ -270,7 +279,10 @@ def update(ctx, config_file, database):
     if not config_dict:
         sys.exit(1)
     config_dict['instance']['config'].update({'db_name': database} if database else {})
-    config_dict.get('group_config').update({'command': 'deployvcmd.commandv.updatedb'})
+    config_dict.get('group_config').update({
+        'command': 'deployvcmd.commandv.updatedb',
+        'update_method': update_method
+    })
     config_obj.generate_configuration(config_dict)
     command = commandv.CommandV(config_obj)
     command.create_trigger()
