@@ -811,6 +811,7 @@ def get_ip_address(ifname):
 
 def is_docker_ip(ip_addr):
     """Recevives an ip and checks if it is in the docker network range"""
+    ip_addr = socket.gethostbyname(ip_addr)
     docker0 = re.sub(r"\.\d{1,3}$", ".0/24", get_ip_address('docker0'))
     return ipaddress.ip_address(decode(ip_addr)) in ipaddress.ip_network(decode(docker0))
 
@@ -970,3 +971,10 @@ def deploy_key(ssh_key, folder_path):
         key_file.write(ssh_key)
     os.chmod(filename, S_IREAD + S_IWRITE)
     return filename
+
+
+def get_main_repo(repos):
+    """Get the main repository from a list of repositories.
+    """
+    main = [r for r in repos if r.get('main_repo')]
+    return main and main[0] or {}
