@@ -156,6 +156,12 @@ class InstanceV(DockerV):
             if not postgres_connection.get('success'):
                 return postgres_connection
         self.set_global_env_vars()
+        # Add the PGHOSt env var here because we only know which value to set after
+        # the container is created, mainly because we don't know if the postgres is in
+        # another container.
+        self.exec_cmd(
+            "/bin/bash -c 'echo export PGHOST={db_host} | tee -a /home/odoo/.profile'"
+            .format(db_host=self.config.get('env_vars').get('db_host')))
         logger.info('Odoo container "%s" created. Ports %s',
                     info.get('name'), info.get('ports'))
         return info
@@ -653,6 +659,7 @@ class InstanceV(DockerV):
             self.config.update({'pg_log_postgres': self.get_specify_volumen(info, destination)})
             self.__full_config.instance_config.get("config").update({'db_host': db_host})
             self.config.get('env_vars').update({
+                'db_port': 5432,
                 'db_host': db_host, 'external_db_port': self.get_db_port(info)})
             return {}
         try:
@@ -787,7 +794,8 @@ class InstanceV(DockerV):
         postgres = PostgresShell(utils.odoo2postgres(postgres_cfg))
         dump_base_name = 'dump.sql' if not jobs else 'database_dump'
         dump_name = path.join(tmp_dir, dump_base_name)
-        dump_name = postgres.dump(database_name, dump_name, jobs=jobs)
+        exclude = self.__full_config.postgres.get("exclude_tables") or ""
+        dump_name = postgres.dump(database_name, dump_name, jobs=jobs, exclude=exclude)
         if not dump_name:
             logger.error('Database could not be dumped')
             return files
